# Change Log
All notable changes to this project will be documented in this file.

## [1.1.1]
Minor bugfix related to adding annotation layers after creating the VideoPointAnnotator interface.

## [1.1.0]

### Changed
Removed the limitation of being able to annotate a maximum of 10 labels. Now, the new limit is 1000 labels. 

## [1.0.2] - 2025-05-07
 
First major release.
